@@ -1,5 +1,3 @@
-package org.apache.maven.plugins.dependency.fromDependencies;
-
 /*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
@@ -9,7 +7,7 @@ package org.apache.maven.plugins.dependency.fromDependencies;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- *  http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -18,13 +16,13 @@ package org.apache.maven.plugins.dependency.fromDependencies;
  * specific language governing permissions and limitations
  * under the License.
  */
+package org.apache.maven.plugins.dependency.fromDependencies;
 
 import java.io.File;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.LinkedHashSet;
 import java.util.Set;
-
 import org.apache.maven.artifact.Artifact;
 import org.apache.maven.artifact.handler.manager.ArtifactHandlerManager;
 import org.apache.maven.plugin.MojoExecutionException;
@@ -39,7 +37,6 @@ import org.apache.maven.project.MavenProject;
 import org.apache.maven.project.ProjectBuilder;
 import org.apache.maven.project.ProjectBuildingException;
 import org.apache.maven.project.ProjectBuildingRequest;
-import org.apache.maven.shared.artifact.ArtifactCoordinate;
 import org.apache.maven.shared.artifact.filter.collection.ArtifactFilterException;
 import org.apache.maven.shared.artifact.filter.collection.ArtifactIdFilter;
 import org.apache.maven.shared.artifact.filter.collection.ArtifactsFilter;
@@ -49,10 +46,11 @@ import org.apache.maven.shared.artifact.filter.collection.GroupIdFilter;
 import org.apache.maven.shared.artifact.filter.collection.ProjectTransitivityFilter;
 import org.apache.maven.shared.artifact.filter.collection.ScopeFilter;
 import org.apache.maven.shared.artifact.filter.collection.TypeFilter;
-import org.apache.maven.shared.repository.RepositoryManager;
-import org.apache.maven.shared.artifact.resolve.ArtifactResolver;
-import org.apache.maven.shared.artifact.resolve.ArtifactResolverException;
-import org.apache.maven.shared.dependencies.resolve.DependencyResolver;
+import org.apache.maven.shared.transfer.artifact.ArtifactCoordinate;
+import org.apache.maven.shared.transfer.artifact.resolve.ArtifactResolver;
+import org.apache.maven.shared.transfer.artifact.resolve.ArtifactResolverException;
+import org.apache.maven.shared.transfer.dependencies.resolve.DependencyResolver;
+import org.apache.maven.shared.transfer.repository.RepositoryManager;
 import org.codehaus.plexus.util.StringUtils;
 
 /**
@@ -61,9 +59,7 @@ import org.codehaus.plexus.util.StringUtils;
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
  * @see org.apache.maven.plugins.dependency.AbstractDependencyMojo
  */
-public abstract class AbstractDependencyFilterMojo
-    extends AbstractDependencyMojo
-{
+public abstract class AbstractDependencyFilterMojo extends AbstractDependencyMojo {
     @Component
     private ArtifactResolver artifactResolver;
 
@@ -78,7 +74,7 @@ public abstract class AbstractDependencyFilterMojo
      *
      * @since 1.0
      */
-    @Parameter( property = "overWriteReleases", defaultValue = "false" )
+    @Parameter(property = "overWriteReleases", defaultValue = "false")
     protected boolean overWriteReleases;
 
     /**
@@ -86,7 +82,7 @@ public abstract class AbstractDependencyFilterMojo
      *
      * @since 1.0
      */
-    @Parameter( property = "overWriteSnapshots", defaultValue = "false" )
+    @Parameter(property = "overWriteSnapshots", defaultValue = "false")
     protected boolean overWriteSnapshots;
 
     /**
@@ -94,7 +90,7 @@ public abstract class AbstractDependencyFilterMojo
      *
      * @since 2.0
      */
-    @Parameter( property = "overWriteIfNewer", defaultValue = "true" )
+    @Parameter(property = "overWriteIfNewer", defaultValue = "true")
     protected boolean overWriteIfNewer;
 
     /**
@@ -102,7 +98,7 @@ public abstract class AbstractDependencyFilterMojo
      *
      * @since 2.0
      */
-    @Parameter( property = "excludeTransitive", defaultValue = "false" )
+    @Parameter(property = "excludeTransitive", defaultValue = "false")
     protected boolean excludeTransitive;
 
     /**
@@ -110,7 +106,7 @@ public abstract class AbstractDependencyFilterMojo
      *
      * @since 2.0
      */
-    @Parameter( property = "includeTypes", defaultValue = "" )
+    @Parameter(property = "includeTypes", defaultValue = "")
     protected String includeTypes;
 
     /**
@@ -118,31 +114,43 @@ public abstract class AbstractDependencyFilterMojo
      *
      * @since 2.0
      */
-    @Parameter( property = "excludeTypes", defaultValue = "" )
+    @Parameter(property = "excludeTypes", defaultValue = "")
     protected String excludeTypes;
 
     /**
-     * Scope to include. An Empty string indicates all scopes (default). The scopes being interpreted are the scopes as
-     * Maven sees them, not as specified in the pom. In summary:
+     * Scope threshold to include. An empty string indicates include all dependencies (default).<br>
+     * The scope threshold value being interpreted is the scope as
+     * Maven filters for creating a classpath, not as specified in the pom. In summary:
      * <ul>
-     * <li><code>runtime</code> scope gives runtime and compile dependencies,</li>
-     * <li><code>compile</code> scope gives compile, provided, and system dependencies,</li>
-     * <li><code>test</code> (default) scope gives all dependencies,</li>
-     * <li><code>provided</code> scope just gives provided dependencies,</li>
-     * <li><code>system</code> scope just gives system dependencies.</li>
+     * <li><code>runtime</code> include scope gives runtime and compile dependencies,</li>
+     * <li><code>compile</code> include scope gives compile, provided, and system dependencies,</li>
+     * <li><code>test</code> include scope gives all dependencies (equivalent to default),</li>
+     * <li><code>provided</code> include scope just gives provided dependencies,</li>
+     * <li><code>system</code> include scope just gives system dependencies.</li>
      * </ul>
      *
      * @since 2.0
      */
-    @Parameter( property = "includeScope", defaultValue = "" )
+    @Parameter(property = "includeScope", defaultValue = "")
     protected String includeScope;
 
     /**
-     * Scope to exclude. An Empty string indicates no scopes (default).
+     * Scope threshold to exclude, if no value is defined for include.
+     * An empty string indicates no dependencies (default).<br>
+     * The scope threshold value being interpreted is the scope as
+     * Maven filters for creating a classpath, not as specified in the pom. In summary:
+     * <ul>
+     * <li><code>runtime</code> exclude scope excludes runtime and compile dependencies,</li>
+     * <li><code>compile</code> exclude scope excludes compile, provided, and system dependencies,</li>
+     * <li><code>test</code> exclude scope excludes all dependencies, then not really a legitimate option: it will
+     * fail, you probably meant to configure includeScope = compile</li>
+     * <li><code>provided</code> exclude scope just excludes provided dependencies,</li>
+     * <li><code>system</code> exclude scope just excludes system dependencies.</li>
+     * </ul>
      *
      * @since 2.0
      */
-    @Parameter( property = "excludeScope", defaultValue = "" )
+    @Parameter(property = "excludeScope", defaultValue = "")
     protected String excludeScope;
 
     /**
@@ -150,7 +158,7 @@ public abstract class AbstractDependencyFilterMojo
      *
      * @since 2.0
      */
-    @Parameter( property = "includeClassifiers", defaultValue = "" )
+    @Parameter(property = "includeClassifiers", defaultValue = "")
     protected String includeClassifiers;
 
     /**
@@ -158,7 +166,7 @@ public abstract class AbstractDependencyFilterMojo
      *
      * @since 2.0
      */
-    @Parameter( property = "excludeClassifiers", defaultValue = "" )
+    @Parameter(property = "excludeClassifiers", defaultValue = "")
     protected String excludeClassifiers;
 
     /**
@@ -166,7 +174,7 @@ public abstract class AbstractDependencyFilterMojo
      *
      * @since 2.0
      */
-    @Parameter( property = "classifier", defaultValue = "" )
+    @Parameter(property = "classifier", defaultValue = "")
     protected String classifier;
 
     /**
@@ -174,7 +182,7 @@ public abstract class AbstractDependencyFilterMojo
      *
      * @since 2.0
      */
-    @Parameter( property = "type", defaultValue = "" )
+    @Parameter(property = "type", defaultValue = "")
     protected String type;
 
     /**
@@ -182,7 +190,7 @@ public abstract class AbstractDependencyFilterMojo
      *
      * @since 2.0
      */
-    @Parameter( property = "excludeArtifactIds", defaultValue = "" )
+    @Parameter(property = "excludeArtifactIds", defaultValue = "")
     protected String excludeArtifactIds;
 
     /**
@@ -190,7 +198,7 @@ public abstract class AbstractDependencyFilterMojo
      *
      * @since 2.0
      */
-    @Parameter( property = "includeArtifactIds", defaultValue = "" )
+    @Parameter(property = "includeArtifactIds", defaultValue = "")
     protected String includeArtifactIds;
 
     /**
@@ -198,7 +206,7 @@ public abstract class AbstractDependencyFilterMojo
      *
      * @since 2.0
      */
-    @Parameter( property = "excludeGroupIds", defaultValue = "" )
+    @Parameter(property = "excludeGroupIds", defaultValue = "")
     protected String excludeGroupIds;
 
     /**
@@ -206,7 +214,7 @@ public abstract class AbstractDependencyFilterMojo
      *
      * @since 2.0
      */
-    @Parameter( property = "includeGroupIds", defaultValue = "" )
+    @Parameter(property = "includeGroupIds", defaultValue = "")
     protected String includeGroupIds;
 
     /**
@@ -214,9 +222,11 @@ public abstract class AbstractDependencyFilterMojo
      *
      * @since 2.0
      */
-    //CHECKSTYLE_OFF: LineLength
-    @Parameter( property = "markersDirectory", defaultValue = "${project.build.directory}/dependency-maven-plugin-markers" )
-    //CHECKSTYLE_ON: LineLength
+    // CHECKSTYLE_OFF: LineLength
+    @Parameter(
+            property = "markersDirectory",
+            defaultValue = "${project.build.directory}/dependency-maven-plugin-markers")
+    // CHECKSTYLE_ON: LineLength
     protected File markersDirectory;
 
     /**
@@ -224,7 +234,7 @@ public abstract class AbstractDependencyFilterMojo
      *
      * @since 2.2
      */
-    @Parameter( property = "mdep.prependGroupId", defaultValue = "false" )
+    @Parameter(property = "mdep.prependGroupId", defaultValue = "false")
     protected boolean prependGroupId = false;
 
     @Component
@@ -247,11 +257,9 @@ public abstract class AbstractDependencyFilterMojo
      * @return A set of artifacts
      * @throws MojoExecutionException in case of errors.
      */
-    protected Set<Artifact> getResolvedDependencies( boolean stopOnFailure )
-        throws MojoExecutionException
+    protected Set<Artifact> getResolvedDependencies(boolean stopOnFailure) throws MojoExecutionException {
 
-    {
-        DependencyStatusSets status = getDependencySets( stopOnFailure );
+        DependencyStatusSets status = getDependencySets(stopOnFailure);
 
         return status.getResolvedDependencies();
     }
@@ -261,10 +269,8 @@ public abstract class AbstractDependencyFilterMojo
      * @return {@link DependencyStatusSets}
      * @throws MojoExecutionException in case of an error.
      */
-    protected DependencyStatusSets getDependencySets( boolean stopOnFailure )
-        throws MojoExecutionException
-    {
-        return getDependencySets( stopOnFailure, false );
+    protected DependencyStatusSets getDependencySets(boolean stopOnFailure) throws MojoExecutionException {
+        return getDependencySets(stopOnFailure, false);
     }
 
     /**
@@ -276,106 +282,97 @@ public abstract class AbstractDependencyFilterMojo
      * @return DependencyStatusSets - Bean of TreeSets that contains information on the projects dependencies
      * @throws MojoExecutionException in case of errors.
      */
-    protected DependencyStatusSets getDependencySets( boolean stopOnFailure, boolean includeParents )
-        throws MojoExecutionException
-    {
+    protected DependencyStatusSets getDependencySets(boolean stopOnFailure, boolean includeParents)
+            throws MojoExecutionException {
         // add filters in well known order, least specific to most specific
         FilterArtifacts filter = new FilterArtifacts();
 
-        filter.addFilter( new ProjectTransitivityFilter( getProject().getDependencyArtifacts(),
-                                                         this.excludeTransitive ) );
+        filter.addFilter(new ProjectTransitivityFilter(getProject().getDependencyArtifacts(), this.excludeTransitive));
 
-        filter.addFilter( new ScopeFilter( DependencyUtil.cleanToBeTokenizedString( this.includeScope ),
-                                           DependencyUtil.cleanToBeTokenizedString( this.excludeScope ) ) );
+        if ("test".equals(this.excludeScope)) {
+            throw new MojoExecutionException("Excluding every artifact inside 'test' resolution scope means "
+                    + "excluding everything: you probably want includeScope='compile', "
+                    + "read parameters documentation for detailed explanations");
+        }
+        filter.addFilter(new ScopeFilter(
+                DependencyUtil.cleanToBeTokenizedString(this.includeScope),
+                DependencyUtil.cleanToBeTokenizedString(this.excludeScope)));
 
-        filter.addFilter( new TypeFilter( DependencyUtil.cleanToBeTokenizedString( this.includeTypes ),
-                                          DependencyUtil.cleanToBeTokenizedString( this.excludeTypes ) ) );
+        filter.addFilter(new TypeFilter(
+                DependencyUtil.cleanToBeTokenizedString(this.includeTypes),
+                DependencyUtil.cleanToBeTokenizedString(this.excludeTypes)));
 
-        filter.addFilter( new ClassifierFilter( DependencyUtil.cleanToBeTokenizedString( this.includeClassifiers ),
-                                                DependencyUtil.cleanToBeTokenizedString( this.excludeClassifiers ) ) );
+        filter.addFilter(new ClassifierFilter(
+                DependencyUtil.cleanToBeTokenizedString(this.includeClassifiers),
+                DependencyUtil.cleanToBeTokenizedString(this.excludeClassifiers)));
 
-        filter.addFilter( new GroupIdFilter( DependencyUtil.cleanToBeTokenizedString( this.includeGroupIds ),
-                                             DependencyUtil.cleanToBeTokenizedString( this.excludeGroupIds ) ) );
+        filter.addFilter(new GroupIdFilter(
+                DependencyUtil.cleanToBeTokenizedString(this.includeGroupIds),
+                DependencyUtil.cleanToBeTokenizedString(this.excludeGroupIds)));
 
-        filter.addFilter( new ArtifactIdFilter( DependencyUtil.cleanToBeTokenizedString( this.includeArtifactIds ),
-                                                DependencyUtil.cleanToBeTokenizedString( this.excludeArtifactIds ) ) );
+        filter.addFilter(new ArtifactIdFilter(
+                DependencyUtil.cleanToBeTokenizedString(this.includeArtifactIds),
+                DependencyUtil.cleanToBeTokenizedString(this.excludeArtifactIds)));
 
         // start with all artifacts.
         Set<Artifact> artifacts = getProject().getArtifacts();
 
-        if ( includeParents )
-        {
+        if (includeParents) {
             // add dependencies parents
-            for ( Artifact dep : new ArrayList<Artifact>( artifacts ) )
-            {
-                addParentArtifacts( buildProjectFromArtifact( dep ), artifacts );
+            for (Artifact dep : new ArrayList<>(artifacts)) {
+                addParentArtifacts(buildProjectFromArtifact(dep), artifacts);
             }
 
             // add current project parent
-            addParentArtifacts( getProject(), artifacts );
+            addParentArtifacts(getProject(), artifacts);
         }
 
         // perform filtering
-        try
-        {
-            artifacts = filter.filter( artifacts );
-        }
-        catch ( ArtifactFilterException e )
-        {
-            throw new MojoExecutionException( e.getMessage(), e );
+        try {
+            artifacts = filter.filter(artifacts);
+        } catch (ArtifactFilterException e) {
+            throw new MojoExecutionException(e.getMessage(), e);
         }
 
         // transform artifacts if classifier is set
         DependencyStatusSets status;
-        if ( StringUtils.isNotEmpty( classifier ) )
-        {
-            status = getClassifierTranslatedDependencies( artifacts, stopOnFailure );
-        }
-        else
-        {
-            status = filterMarkedDependencies( artifacts );
+        if (StringUtils.isNotEmpty(classifier)) {
+            status = getClassifierTranslatedDependencies(artifacts, stopOnFailure);
+        } else {
+            status = filterMarkedDependencies(artifacts);
         }
 
         return status;
     }
 
-    private MavenProject buildProjectFromArtifact( Artifact artifact )
-        throws MojoExecutionException
-    {
-        try
-        {
-            return projectBuilder.build( artifact, session.getProjectBuildingRequest() ).getProject();
-        }
-        catch ( ProjectBuildingException e )
-        {
-            throw new MojoExecutionException( e.getMessage(), e );
+    private MavenProject buildProjectFromArtifact(Artifact artifact) throws MojoExecutionException {
+        try {
+            return projectBuilder
+                    .build(artifact, session.getProjectBuildingRequest())
+                    .getProject();
+        } catch (ProjectBuildingException e) {
+            throw new MojoExecutionException(e.getMessage(), e);
         }
     }
 
-    private void addParentArtifacts( MavenProject project, Set<Artifact> artifacts )
-        throws MojoExecutionException
-    {
-        while ( project.hasParent() )
-        {
+    private void addParentArtifacts(MavenProject project, Set<Artifact> artifacts) throws MojoExecutionException {
+        while (project.hasParent()) {
             project = project.getParent();
 
-            if ( artifacts.contains( project.getArtifact() ) )
-            {
+            if (artifacts.contains(project.getArtifact())) {
                 // artifact already in the set
                 break;
             }
-            try
-            {
+            try {
                 ProjectBuildingRequest buildingRequest = newResolveArtifactProjectBuildingRequest();
 
-                Artifact resolvedArtifact =
-                    artifactResolver.resolveArtifact( buildingRequest, project.getArtifact() ).getArtifact();
+                Artifact resolvedArtifact = artifactResolver
+                        .resolveArtifact(buildingRequest, project.getArtifact())
+                        .getArtifact();
 
-                artifacts.add( resolvedArtifact );
-            }
-            catch ( ArtifactResolverException e )
-            {
-                throw new MojoExecutionException( e.getMessage(), e );
+                artifacts.add(resolvedArtifact);
+            } catch (ArtifactResolverException e) {
+                throw new MojoExecutionException(e.getMessage(), e);
             }
         }
     }
@@ -388,38 +385,36 @@ public abstract class AbstractDependencyFilterMojo
      * @return DependencyStatusSets - Bean of TreeSets that contains information on the projects dependencies
      * @throws MojoExecutionException in case of an error.
      */
-    protected DependencyStatusSets getClassifierTranslatedDependencies( Set<Artifact> artifacts, boolean stopOnFailure )
-        throws MojoExecutionException
-    {
-        Set<Artifact> unResolvedArtifacts = new LinkedHashSet<Artifact>();
+    protected DependencyStatusSets getClassifierTranslatedDependencies(Set<Artifact> artifacts, boolean stopOnFailure)
+            throws MojoExecutionException {
+        Set<Artifact> unResolvedArtifacts = new LinkedHashSet<>();
         Set<Artifact> resolvedArtifacts = artifacts;
         DependencyStatusSets status = new DependencyStatusSets();
 
         // possibly translate artifacts into a new set of artifacts based on the
         // classifier and type
         // if this did something, we need to resolve the new artifacts
-        if ( StringUtils.isNotEmpty( classifier ) )
-        {
+        if (StringUtils.isNotEmpty(classifier)) {
             ArtifactTranslator translator =
-                new ClassifierTypeTranslator( artifactHandlerManager, this.classifier, this.type );
-            Collection<ArtifactCoordinate> coordinates = translator.translate( artifacts, getLog() );
+                    new ClassifierTypeTranslator(artifactHandlerManager, this.classifier, this.type);
+            Collection<ArtifactCoordinate> coordinates = translator.translate(artifacts, getLog());
 
-            status = filterMarkedDependencies( artifacts );
+            status = filterMarkedDependencies(artifacts);
 
             // the unskipped artifacts are in the resolved set.
             artifacts = status.getResolvedDependencies();
 
             // resolve the rest of the artifacts
-            resolvedArtifacts = resolve( new LinkedHashSet<ArtifactCoordinate>( coordinates ), stopOnFailure );
+            resolvedArtifacts = resolve(new LinkedHashSet<>(coordinates), stopOnFailure);
 
             // calculate the artifacts not resolved.
-            unResolvedArtifacts.addAll( artifacts );
-            unResolvedArtifacts.removeAll( resolvedArtifacts );
+            unResolvedArtifacts.addAll(artifacts);
+            unResolvedArtifacts.removeAll(resolvedArtifacts);
         }
 
         // return a bean of all 3 sets.
-        status.setResolvedDependencies( resolvedArtifacts );
-        status.setUnResolvedDependencies( unResolvedArtifacts );
+        status.setResolvedDependencies(resolvedArtifacts);
+        status.setUnResolvedDependencies(unResolvedArtifacts);
 
         return status;
     }
@@ -431,30 +426,24 @@ public abstract class AbstractDependencyFilterMojo
      * @return status set {@link DependencyStatusSets}.
      * @throws MojoExecutionException in case of an error.
      */
-    protected DependencyStatusSets filterMarkedDependencies( Set<Artifact> artifacts )
-        throws MojoExecutionException
-    {
+    protected DependencyStatusSets filterMarkedDependencies(Set<Artifact> artifacts) throws MojoExecutionException {
         // remove files that have markers already
         FilterArtifacts filter = new FilterArtifacts();
         filter.clearFilters();
-        filter.addFilter( getMarkedArtifactFilter() );
+        filter.addFilter(getMarkedArtifactFilter());
 
         Set<Artifact> unMarkedArtifacts;
-        try
-        {
-            unMarkedArtifacts = filter.filter( artifacts );
-        }
-        catch ( ArtifactFilterException e )
-        {
-            throw new MojoExecutionException( e.getMessage(), e );
+        try {
+            unMarkedArtifacts = filter.filter(artifacts);
+        } catch (ArtifactFilterException e) {
+            throw new MojoExecutionException(e.getMessage(), e);
         }
 
         // calculate the skipped artifacts
-        Set<Artifact> skippedArtifacts = new LinkedHashSet<Artifact>();
-        skippedArtifacts.addAll( artifacts );
-        skippedArtifacts.removeAll( unMarkedArtifacts );
+        Set<Artifact> skippedArtifacts = new LinkedHashSet<>(artifacts);
+        skippedArtifacts.removeAll(unMarkedArtifacts);
 
-        return new DependencyStatusSets( unMarkedArtifacts, null, skippedArtifacts );
+        return new DependencyStatusSets(unMarkedArtifacts, null, skippedArtifacts);
     }
 
     /**
@@ -464,27 +453,23 @@ public abstract class AbstractDependencyFilterMojo
      * @return the resolved artifacts. {@link Artifact}.
      * @throws MojoExecutionException in case of error.
      */
-    protected Set<Artifact> resolve( Set<ArtifactCoordinate> coordinates, boolean stopOnFailure )
-        throws MojoExecutionException
-    {
+    protected Set<Artifact> resolve(Set<ArtifactCoordinate> coordinates, boolean stopOnFailure)
+            throws MojoExecutionException {
         ProjectBuildingRequest buildingRequest = newResolveArtifactProjectBuildingRequest();
 
-        Set<Artifact> resolvedArtifacts = new LinkedHashSet<Artifact>();
-        for ( ArtifactCoordinate coordinate : coordinates )
-        {
-            try
-            {
-                Artifact artifact = artifactResolver.resolveArtifact( buildingRequest, coordinate ).getArtifact();
-                resolvedArtifacts.add( artifact );
-            }
-            catch ( ArtifactResolverException ex )
-            {
+        Set<Artifact> resolvedArtifacts = new LinkedHashSet<>();
+        for (ArtifactCoordinate coordinate : coordinates) {
+            try {
+                Artifact artifact = artifactResolver
+                        .resolveArtifact(buildingRequest, coordinate)
+                        .getArtifact();
+                resolvedArtifacts.add(artifact);
+            } catch (ArtifactResolverException ex) {
                 // an error occurred during resolution, log it an continue
-                getLog().debug( "error resolving: " + coordinate );
-                getLog().debug( ex );
-                if ( stopOnFailure )
-                {
-                    throw new MojoExecutionException( "error resolving: " + coordinate, ex );
+                getLog().debug("error resolving: " + coordinate);
+                getLog().debug(ex);
+                if (stopOnFailure) {
+                    throw new MojoExecutionException("error resolving: " + coordinate, ex);
                 }
             }
         }
@@ -494,16 +479,14 @@ public abstract class AbstractDependencyFilterMojo
     /**
      * @return Returns the markersDirectory.
      */
-    public File getMarkersDirectory()
-    {
+    public File getMarkersDirectory() {
         return this.markersDirectory;
     }
 
     /**
      * @param theMarkersDirectory The markersDirectory to set.
      */
-    public void setMarkersDirectory( File theMarkersDirectory )
-    {
+    public void setMarkersDirectory(File theMarkersDirectory) {
         this.markersDirectory = theMarkersDirectory;
     }
 
@@ -512,40 +495,35 @@ public abstract class AbstractDependencyFilterMojo
     /**
      * @return true, if the groupId should be prepended to the filename.
      */
-    public boolean isPrependGroupId()
-    {
+    public boolean isPrependGroupId() {
         return prependGroupId;
     }
 
     /**
      * @param prependGroupId - true if the groupId must be prepended during the copy.
      */
-    public void setPrependGroupId( boolean prependGroupId )
-    {
+    public void setPrependGroupId(boolean prependGroupId) {
         this.prependGroupId = prependGroupId;
     }
 
     /**
      * @return {@link #artifactResolver}
      */
-    protected final ArtifactResolver getArtifactResolver()
-    {
+    protected final ArtifactResolver getArtifactResolver() {
         return artifactResolver;
     }
 
     /**
      * @return {@link #dependencyResolver}
      */
-    protected final DependencyResolver getDependencyResolver()
-    {
+    protected final DependencyResolver getDependencyResolver() {
         return dependencyResolver;
     }
 
     /**
      * @return {@link #repositoryManager}
      */
-    protected final RepositoryManager getRepositoryManager()
-    {
+    protected final RepositoryManager getRepositoryManager() {
         return repositoryManager;
     }
 }
