@@ -1,6 +1,4 @@
-package org.apache.maven.plugins.dependency.utils.translators;
-
-/* 
+/*
  * Licensed to the Apache Software Foundation (ASF) under one
  * or more contributor license agreements.  See the NOTICE file
  * distributed with this work for additional information
@@ -9,31 +7,30 @@ package org.apache.maven.plugins.dependency.utils.translators;
  * "License"); you may not use this file except in compliance
  * with the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *   http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
  * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
  * KIND, either express or implied.  See the License for the
  * specific language governing permissions and limitations
- * under the License.    
+ * under the License.
  */
+package org.apache.maven.plugins.dependency.utils.translators;
 
 import java.util.Set;
-
 import org.apache.maven.artifact.Artifact;
 import org.apache.maven.plugin.logging.Log;
-import org.apache.maven.shared.artifact.ArtifactCoordinate;
+import org.apache.maven.shared.transfer.artifact.ArtifactCoordinate;
 
 /**
  * @author <a href="mailto:brianf@apache.org">Brian Fox</a>
  */
-public interface ArtifactTranslator
-{
+public interface ArtifactTranslator {
     /**
      * @param artifacts set of {@link Artifact}s.
      * @param log {@link Log}
      * @return {@link ArtifactCoordinate}
      */
-    Set<ArtifactCoordinate> translate( Set<Artifact> artifacts, Log log );
+    Set<ArtifactCoordinate> translate(Set<Artifact> artifacts, Log log);
 }
